@@ -215,3 +215,65 @@ def test_history_getitem(index, exp, hist, xonsh_builtins):
         assert [(e.cmd, e.out, e.rtn, e.ts) for e in entry] == exp
     else:
         assert (entry.cmd, entry.out, entry.rtn, entry.ts) == exp
+
+
+def test_hist_clear_cmd(hist, xonsh_builtins, capsys, tmpdir):
+    """Verify that the CLI history clear command works."""
+    xonsh_builtins.__xonsh__.env.update({"XONSH_DATA_DIR": str(tmpdir)})
+    xonsh_builtins.__xonsh__.history = hist
+    xonsh_builtins.__xonsh__.env["HISTCONTROL"] = set()
+
+    for ts, cmd in enumerate(CMDS):  # populate the shell history
+        hist.append({"inp": cmd, "rtn": 0, "ts": (ts + 1, ts + 1.5)})
+    assert len(xonsh_builtins.__xonsh__.history) == 6
+
+    history_main(["clear"])
+
+    out, err = capsys.readouterr()
+    assert err.rstrip() == "History cleared"
+    assert len(xonsh_builtins.__xonsh__.history) == 0
+
+
+def test_hist_off_cmd(hist, xonsh_builtins, capsys, tmpdir):
+    """Verify that the CLI history off command works."""
+    xonsh_builtins.__xonsh__.env.update({"XONSH_DATA_DIR": str(tmpdir)})
+    xonsh_builtins.__xonsh__.history = hist
+    xonsh_builtins.__xonsh__.env["HISTCONTROL"] = set()
+
+    for ts, cmd in enumerate(CMDS):  # populate the shell history
+        hist.append({"inp": cmd, "rtn": 0, "ts": (ts + 1, ts + 1.5)})
+    assert len(xonsh_builtins.__xonsh__.history) == 6
+
+    history_main(["off"])
+
+    out, err = capsys.readouterr()
+    assert err.rstrip() == "History off"
+    assert len(xonsh_builtins.__xonsh__.history) == 0
+
+    for ts, cmd in enumerate(CMDS):  # attempt to populate the shell history
+        hist.append({"inp": cmd, "rtn": 0, "ts": (ts + 1, ts + 1.5)})
+
+    assert len(xonsh_builtins.__xonsh__.history) == 0
+
+
+def test_hist_on_cmd(hist, xonsh_builtins, capsys, tmpdir):
+    """Verify that the CLI history on command works."""
+    xonsh_builtins.__xonsh__.env.update({"XONSH_DATA_DIR": str(tmpdir)})
+    xonsh_builtins.__xonsh__.history = hist
+    xonsh_builtins.__xonsh__.env["HISTCONTROL"] = set()
+
+    for ts, cmd in enumerate(CMDS):  # populate the shell history
+        hist.append({"inp": cmd, "rtn": 0, "ts": (ts + 1, ts + 1.5)})
+    assert len(xonsh_builtins.__xonsh__.history) == 6
+
+    history_main(["off"])
+    history_main(["on"])
+
+    out, err = capsys.readouterr()
+    assert err.rstrip().endswith("History on")
+    assert len(xonsh_builtins.__xonsh__.history) == 0
+
+    for ts, cmd in enumerate(CMDS):  # populate the shell history
+        hist.append({"inp": cmd, "rtn": 0, "ts": (ts + 1, ts + 1.5)})
+
+    assert len(xonsh_builtins.__xonsh__.history) == 6
